#ifndef NT2_INCLUDE_FUNCTIONS_COTPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COTPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cotpi.hpp>

#endif
